@@ -1,5 +1,5 @@
-// Copyright (C) 2010-2011 NICTA (www.nicta.com.au)
-// Copyright (C) 2010-2011 Conrad Sanderson
+// Copyright (C) 2010-2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2010-2012 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -59,8 +59,10 @@ class Proxy< Mat<eT> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                   const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<eT>& X) const { return (&Q == &X); }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&Q) == void_ptr(&X)); }
   };
 
 
@@ -93,8 +95,10 @@ class Proxy< Col<eT> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                   const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<eT>& X) const { return (&Q == &X); }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&Q) == void_ptr(&X)); }
   };
 
 
@@ -127,8 +131,10 @@ class Proxy< Row<eT> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                   const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<eT>& X) const { return (&Q == &X); }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&Q) == void_ptr(&X)); }
   };
 
 
@@ -161,8 +167,10 @@ class Proxy< Gen<eT, gen_type > >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                        const { return Q;     }
-  arma_inline bool    is_alias(const Mat<elem_type>&) const { return false; }
+  arma_inline ea_type get_ea() const { return Q; }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
   };
 
 
@@ -195,8 +203,10 @@ class Proxy< Op<T1, op_type> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                        const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<elem_type>&) const { return false;      }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
   };
 
 
@@ -229,8 +239,10 @@ class Proxy< Glue<T1, T2, glue_type> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                        const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<elem_type>&) const { return false;      }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
   };
 
 
@@ -263,8 +275,10 @@ class Proxy< subview<eT> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                   const { return Q;              }
-  arma_inline bool    is_alias(const Mat<eT>& X) const { return (&(Q.m) == &X); }
+  arma_inline ea_type get_ea() const { return Q; }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&(Q.m)) == void_ptr(&X)); }
   };
 
 
@@ -297,8 +311,10 @@ class Proxy< subview_elem1<eT,T1> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                 const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<eT>&) const { return false;      }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
   };
 
 
@@ -331,8 +347,10 @@ class Proxy< diagview<eT> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                   const { return Q;              }
-  arma_inline bool    is_alias(const Mat<eT>& X) const { return (&(Q.m) == &X); }
+  arma_inline ea_type get_ea() const { return Q; }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (void_ptr(&(Q.m)) == void_ptr(&X)); }
   };
 
 
@@ -366,8 +384,10 @@ class Proxy< eOp<T1, eop_type > >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                          const { return Q;               }
-  arma_inline bool    is_alias(const Mat<elem_type>& X) const { return Q.P.is_alias(X); }
+  arma_inline ea_type get_ea() const { return Q; }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return Q.P.is_alias(X); }
   };
 
 
@@ -400,8 +420,10 @@ class Proxy< eGlue<T1, T2, eglue_type > >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];           }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row, col); }
   
-  arma_inline ea_type get_ea()                          const { return Q;                                      }
-  arma_inline bool    is_alias(const Mat<elem_type>& X) const { return (Q.P1.is_alias(X) || Q.P2.is_alias(X)); }
+  arma_inline ea_type get_ea() const { return Q; }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>& X) const { return (Q.P1.is_alias(X) || Q.P2.is_alias(X)); }
   };
 
 
@@ -434,8 +456,10 @@ class Proxy< mtOp<out_eT, T1, op_type> >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];          }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row,col); }
   
-  arma_inline ea_type get_ea()                     const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<out_eT>&) const { return false;      }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
   };
 
 
@@ -468,8 +492,10 @@ class Proxy< mtGlue<out_eT, T1, T2, glue_type > >
   arma_inline elem_type operator[] (const uword i)                    const { return Q[i];          }
   arma_inline elem_type at         (const uword row, const uword col) const { return Q.at(row,col); }
   
-  arma_inline ea_type get_ea()                     const { return Q.memptr(); }
-  arma_inline bool    is_alias(const Mat<out_eT>&) const { return false;      }
+  arma_inline ea_type get_ea() const { return Q.memptr(); }
+  
+  template<typename eT2>
+  arma_inline bool is_alias(const Mat<eT2>&) const { return false; }
   };
 
 
