@@ -24,12 +24,26 @@
 
 
 #if defined(ARMA_BLAS_UNDERSCORE)
-  #define arma_fortran2(function) function##_
+  #define arma_fortran2_noprefix(function) function##_
+  #define arma_fortran2_prefix(function)   wrapper_##function##_
 #else
-  #define arma_fortran2(function) function
+  #define arma_fortran2_prefix(function)   wrapper_##function
+  #define arma_fortran2_noprefix(function) function
 #endif
 
-#define arma_fortran(function) arma_fortran2(function)
+#if defined(ARMA_USE_WRAPPER)
+  #define arma_fortran(function) arma_fortran2_prefix(function)
+  #define arma_atlas(function)   wrapper_##function
+#else
+  #define arma_fortran(function) arma_fortran2_noprefix(function)
+  #define arma_atlas(function)   function
+#endif
+
+#define arma_fortran_prefix(function)   arma_fortran2_prefix(function)
+#define arma_fortran_noprefix(function) arma_fortran2_noprefix(function)
+
+
+#define ARMA_INCFILE_WRAP(x) <x>
 
 
 #if defined(__INTEL_COMPILER)
