@@ -25,7 +25,7 @@
 template<typename T1>
 arma_inline
 const Op<T1, op_max>
-max(const Base<typename T1::elem_type,T1>& X, const u32 dim = 0)
+max(const Base<typename T1::elem_type,T1>& X, const uword dim = 0)
   {
   arma_extra_debug_sigprint();
 
@@ -42,7 +42,7 @@ max(const Row<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  const u32 A_n_elem = A.n_elem;
+  const uword A_n_elem = A.n_elem;
   
   arma_debug_check( (A_n_elem == 0), "max(): given object has no elements" );
   
@@ -60,7 +60,7 @@ max(const Col<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  const u32 A_n_elem = A.n_elem;
+  const uword A_n_elem = A.n_elem;
   
   arma_debug_check( (A_n_elem == 0), "max(): given object has no elements" );
   
@@ -86,7 +86,7 @@ max(const Op<T1, op_max>& in)
   const unwrap<T1> tmp1(in.m);
   const Mat<eT>& X = tmp1.M;
   
-  const u32 X_n_elem = X.n_elem;
+  const uword X_n_elem = X.n_elem;
   
   arma_debug_check( (X_n_elem == 0), "max(): given object has no elements" );
   
@@ -98,7 +98,7 @@ max(const Op<T1, op_max>& in)
 template<typename T1>
 arma_inline
 const Op< Op<T1, op_max>, op_max>
-max(const Op<T1, op_max>& in, const u32 dim)
+max(const Op<T1, op_max>& in, const uword dim)
   {
   arma_extra_debug_sigprint();
   
@@ -180,7 +180,7 @@ max(const subview_elem1<eT,T1>& A)
   
   const Mat<eT> X(A);
   
-  const u32 X_n_elem = X.n_elem;
+  const uword X_n_elem = X.n_elem;
   
   arma_debug_check( (X_n_elem == 0), "max(): given object has no elements" );
   
