@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2010 Conrad Sanderson
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -35,32 +35,32 @@ randu()
 
 //! Generate a vector with all elements set to random values in the [0,1] interval (uniform distribution)
 arma_inline
-const eOp<colvec, eop_randu>
-randu(const u32 n_elem)
+const Gen<vec::elem_type, gen_randu>
+randu(const uword n_elem)
   {
   arma_extra_debug_sigprint();
   
-  return eOp<colvec, eop_randu>(n_elem, 1);
+  return Gen<vec::elem_type, gen_randu>(n_elem, 1);
   }
 
 
 
 template<typename vec_type>
 arma_inline
-const eOp<vec_type, eop_randu>
-randu(const u32 n_elem, const typename arma_Mat_Col_Row_only<vec_type>::result* junk = 0)
+const Gen<typename vec_type::elem_type, gen_randu>
+randu(const uword n_elem, const arma_empty_class junk1 = arma_empty_class(), const typename arma_Mat_Col_Row_only<vec_type>::result* junk2 = 0)
   {
   arma_extra_debug_sigprint();
-  
-  arma_ignore(junk);
+  arma_ignore(junk1);
+  arma_ignore(junk2);
   
   if(is_Row<vec_type>::value == true)
     {
-    return eOp<vec_type, eop_randu>(1, n_elem);
+    return Gen<typename vec_type::elem_type, gen_randu>(1, n_elem);
     }
   else
     {
-    return eOp<vec_type, eop_randu>(n_elem, 1);
+    return Gen<typename vec_type::elem_type, gen_randu>(n_elem, 1);
     }
   }
 
@@ -68,51 +68,49 @@ randu(const u32 n_elem, const typename arma_Mat_Col_Row_only<vec_type>::result*
 
 //! Generate a dense matrix with all elements set to random values in the [0,1] interval (uniform distribution)
 arma_inline
-const eOp<mat, eop_randu>
-randu(const u32 n_rows, const u32 n_cols)
+const Gen<mat::elem_type, gen_randu>
+randu(const uword n_rows, const uword n_cols)
   {
   arma_extra_debug_sigprint();
   
-  return eOp<mat, eop_randu>(n_rows, n_cols);
+  return Gen<mat::elem_type, gen_randu>(n_rows, n_cols);
   }
 
 
 
 template<typename mat_type>
 arma_inline
-const eOp<mat_type, eop_randu>
-randu(const u32 n_rows, const u32 n_cols, const typename arma_Mat_Col_Row_only<mat_type>::result* junk = 0)
+const Gen<typename mat_type::elem_type, gen_randu>
+randu(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_only<mat_type>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
-  
   arma_ignore(junk);
   
-  return eOp<mat_type, eop_randu>(n_rows, n_cols);
+  return Gen<typename mat_type::elem_type, gen_randu>(n_rows, n_cols);
   }
 
 
 
 arma_inline
-const eOpCube<cube, eop_randu>
-randu(const u32 n_rows, const u32 n_cols, const u32 n_slices)
+const GenCube<cube::elem_type, gen_randu>
+randu(const uword n_rows, const uword n_cols, const uword n_slices)
   {
   arma_extra_debug_sigprint();
   
-  return eOpCube<cube, eop_randu>(n_rows, n_cols, n_slices);
+  return GenCube<cube::elem_type, gen_randu>(n_rows, n_cols, n_slices);
   }
 
 
 
 template<typename cube_type>
 arma_inline
-const eOpCube<cube_type, eop_randu>
-randu(const u32 n_rows, const u32 n_cols, const u32 n_slices, const typename arma_Cube_only<cube_type>::result* junk = 0)
+const GenCube<typename cube_type::elem_type, gen_randu>
+randu(const uword n_rows, const uword n_cols, const uword n_slices, const typename arma_Cube_only<cube_type>::result* junk = 0)
   {
   arma_extra_debug_sigprint();
-  
   arma_ignore(junk);
   
-  return eOpCube<cube_type, eop_randu>(n_rows, n_cols, n_slices);
+  return GenCube<typename cube_type::elem_type, gen_randu>(n_rows, n_cols, n_slices);
   }
 
 
