@@ -39,9 +39,9 @@ glue_conv::apply(Mat<typename T1::elem_type>& out, const Glue<T1,T2,glue_conv>&
   const Mat<eT>& x = (A.n_elem <= B.n_elem) ? B : A;
   
   
-  const u32   h_n_elem = h.n_elem;
-  const u32   x_n_elem = x.n_elem;
-  const u32 out_n_elem = h_n_elem + x_n_elem - 1;
+  const uword   h_n_elem = h.n_elem;
+  const uword   x_n_elem = x.n_elem;
+  const uword out_n_elem = h_n_elem + x_n_elem - 1;
   
   
   if( (h_n_elem == 0) || (x_n_elem == 0) )
@@ -59,13 +59,13 @@ glue_conv::apply(Mat<typename T1::elem_type>& out, const Glue<T1,T2,glue_conv>&
         eT* out_mem = out.memptr();
   
   
-  for(u32 out_i = 0; out_i < (h_n_elem-1); ++out_i)
+  for(uword out_i = 0; out_i < (h_n_elem-1); ++out_i)
     {
     eT acc = eT(0);
     
-    u32 h_i = out_i;
+    uword h_i = out_i;
     
-    for(u32 x_i = 0; x_i <= out_i; ++x_i, --h_i)
+    for(uword x_i = 0; x_i <= out_i; ++x_i, --h_i)
       {
       acc += h_mem[h_i] * x_mem[x_i];
       }
@@ -74,13 +74,13 @@ glue_conv::apply(Mat<typename T1::elem_type>& out, const Glue<T1,T2,glue_conv>&
     }
   
   
-  for(u32 out_i = h_n_elem-1; out_i < out_n_elem - (h_n_elem-1); ++out_i)
+  for(uword out_i = h_n_elem-1; out_i < out_n_elem - (h_n_elem-1); ++out_i)
     {
     eT acc = eT(0);
    
-    u32 h_i = h_n_elem - 1;
+    uword h_i = h_n_elem - 1;
     
-    for(u32 x_i = out_i - h_n_elem + 1; x_i <= out_i; ++x_i, --h_i)
+    for(uword x_i = out_i - h_n_elem + 1; x_i <= out_i; ++x_i, --h_i)
       {
       acc += h_mem[h_i] * x_mem[x_i];
       }
@@ -89,13 +89,13 @@ glue_conv::apply(Mat<typename T1::elem_type>& out, const Glue<T1,T2,glue_conv>&
     }
   
   
-  for(u32 out_i = out_n_elem - (h_n_elem-1); out_i < out_n_elem; ++out_i)
+  for(uword out_i = out_n_elem - (h_n_elem-1); out_i < out_n_elem; ++out_i)
     {
     eT acc = eT(0);
     
-    u32 h_i = h_n_elem - 1;
+    uword h_i = h_n_elem - 1;
     
-    for(u32 x_i = out_i - h_n_elem + 1; x_i < x_n_elem; ++x_i, --h_i)
+    for(uword x_i = out_i - h_n_elem + 1; x_i < x_n_elem; ++x_i, --h_i)
       {
       acc += h_mem[h_i] * x_mem[x_i];
       }
