@@ -32,22 +32,22 @@ op_repmat::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_repmat>& in)
   const unwrap_check<T1> tmp(in.m, out);
   const Mat<eT>& X     = tmp.M;
   
-  const u32 copies_per_row = in.aux_u32_a;
-  const u32 copies_per_col = in.aux_u32_b;
+  const uword copies_per_row = in.aux_uword_a;
+  const uword copies_per_col = in.aux_uword_b;
   
-  const u32 X_n_rows = X.n_rows;
-  const u32 X_n_cols = X.n_cols;
+  const uword X_n_rows = X.n_rows;
+  const uword X_n_cols = X.n_cols;
   
   out.set_size(X_n_rows * copies_per_row, X_n_cols * copies_per_col);
   
-  const u32 out_n_rows = out.n_rows;
-  const u32 out_n_cols = out.n_cols;
+  const uword out_n_rows = out.n_rows;
+  const uword out_n_cols = out.n_cols;
   
   if( (out_n_rows > 0) && (out_n_cols > 0) )
     {
-    for(u32 col = 0; col < out_n_cols; col += X_n_cols)
+    for(uword col = 0; col < out_n_cols; col += X_n_cols)
       {
-      for(u32 row = 0; row < out_n_rows; row += X_n_rows)
+      for(uword row = 0; row < out_n_rows; row += X_n_rows)
         {
         out.submat(row, col, row+X_n_rows-1, col+X_n_cols-1) = X;
         }
